@@ -73,7 +73,7 @@ class ELFiClient(ELFiBaseClient):
     
     def create_increase_market_order(self, symbol, marginToken, orderSide: OrderSide, orderMargin, leverage, isCrossMargin=True, executionFee=-1):
         if executionFee < 0:
-            executionFee = GAS_LIMIT['placeIncreaseOrderGasFeeLimit'] * self.w3.eth.gas_price
+            executionFee = int(GAS_LIMIT['placeDecreaseOrderGasFeeLimit'] * self.w3.eth.gas_price * 5 / 4)
         params = self._get_order_params()
         params.update({
             "symbol": encode_bytes32(symbol),
@@ -82,7 +82,7 @@ class ELFiClient(ELFiBaseClient):
             "orderSide": orderSide.value,
             "orderMargin": orderMargin,
             "leverage": leverage,
-            "executionFee": executionFee,
+            "executionFee": int(executionFee),
             })
         if (isCrossMargin is False):
             self._token_approve(marginToken, orderMargin)
@@ -90,7 +90,7 @@ class ELFiClient(ELFiBaseClient):
     
     def create_increase_limit_order(self, symbol, marginToken, orderSide: OrderSide, orderMargin, leverage, triggerPrice, isCrossMargin=True, executionFee=-1):
         if executionFee < 0:
-            executionFee = GAS_LIMIT['placeIncreaseOrderGasFeeLimit'] * self.w3.eth.gas_price
+            executionFee = int(GAS_LIMIT['placeDecreaseOrderGasFeeLimit'] * self.w3.eth.gas_price * 5 / 4)
         params = self._get_order_params()
         params.update({
             "symbol": encode_bytes32(symbol),
@@ -101,7 +101,7 @@ class ELFiClient(ELFiBaseClient):
             "leverage": leverage,
             "orderType": OrderType.LIMIT.value,
             "trigger_price": triggerPrice,
-            "executionFee": executionFee,
+            "executionFee": int(executionFee),
             })
         if (isCrossMargin is False):
             self._token_approve(marginToken, orderMargin)
@@ -109,7 +109,7 @@ class ELFiClient(ELFiBaseClient):
     
     def create_decrease_market_order(self, symbol, marginToken, orderSide: OrderSide, qty, isCrossMargin=True, executionFee=-1):
         if executionFee < 0:
-            executionFee = GAS_LIMIT['placeDecreaseOrderGasFeeLimit'] * self.w3.eth.gas_price
+            executionFee = int(GAS_LIMIT['placeDecreaseOrderGasFeeLimit'] * self.w3.eth.gas_price * 5 / 4)
         params = self._get_order_params()
         params.update({
             "symbol": encode_bytes32(symbol),
@@ -118,14 +118,14 @@ class ELFiClient(ELFiBaseClient):
             "posSide": PositionSide.DECRASE.value,
             "orderSide": orderSide.value,
             "qty": qty,
-            "executionFee": executionFee,
+            "executionFee": int(executionFee),
             })
         
         return self.create_order_request(params)
     
     def create_stop_order(self, symbol, marginToken, orderSide: OrderSide, qty, triggerPrice, stopType: StopType, isCrossMargin=True, executionFee=-1):
         if executionFee < 0:
-            executionFee = GAS_LIMIT['placeDecreaseOrderGasFeeLimit'] * self.w3.eth.gas_price
+            executionFee = int(GAS_LIMIT['placeDecreaseOrderGasFeeLimit'] * self.w3.eth.gas_price * 5 / 4)
         params = self._get_order_params()
         params.update({
             "symbol": encode_bytes32(symbol),
@@ -137,14 +137,16 @@ class ELFiClient(ELFiBaseClient):
             "orderType": OrderType.STOP.value,
             "stopType": stopType.value,
             "trigger_price": triggerPrice,
-            "executionFee": executionFee,
+            "executionFee": int(executionFee),
             })
         return self.create_order_request(params)
     
     def create_order_request(self, params):
+        executionFee = int(params['executionFee'])
         params = tuple(params.values())
         tx = self._facet_contract("OrderFacet").functions.createOrderRequest(params).build_transaction({
                 'from': self.account,
+                'value': executionFee,
                 'nonce': self.w3.eth.get_transaction_count(self.account)
             })
         return self._sign_and_send_transaction(tx)
@@ -166,9 +168,10 @@ class ELFiClient(ELFiBaseClient):
     
     def withdraw(self, token, amount, isWithdrawMax=False, executionFee=-1):
         if executionFee < 0:
-            executionFee = GAS_LIMIT['withdrawGasFeeLimit'] * self.w3.eth.gas_price
+            executionFee = int(GAS_LIMIT['placeDecreaseOrderGasFeeLimit'] * self.w3.eth.gas_price * 5 / 4)
         tx = self._facet_contract("AccountFacet").functions.createWithdrawRequest(token, amount, executionFee, isWithdrawMax).build_transaction({
                 'from': self.account,
+                'value': executionFee,
                 'nonce': self.w3.eth.get_transaction_count(self.account)
             })
         return self._sign_and_send_transaction(tx)
